@@ -103,9 +103,6 @@
 # Bind only to localhost by default:
 SOLR_OPTS="$SOLR_OPTS -Djetty.host=localhost"
 
-# https://solr.apache.org/security.html#apache-solr-affected-by-apache-log4j-cve-2021-44228
-SOLR_OPTS="$SOLR_OPTS -Dlog4j2.formatMsgNoLookups=true"
-
 # Location where the bin/solr script will save PID files for running instances
 # If not set, the script will create PID files in $SOLR_TIP/bin
 SOLR_PID_DIR=/var/db/solr
@@ -256,3 +253,7 @@ SOLR_LOGS_DIR=/var/log/solr
 # You can test this behaviour by setting SOLR_HEAP=25m
 #SOLR_HEAP_DUMP=true
 #SOLR_HEAP_DUMP_DIR=/var/log/dumps
+
+# Some previous versions of Solr use an outdated log4j dependency. If you are unable to use at least log4j version 2.15.0
+# then enable the following setting to address CVE-2021-44228
+# SOLR_OPTS="$SOLR_OPTS -Dlog4j2.formatMsgNoLookups=true"
